const bestPractice = require('./rules/bestPractice');
const errors = require('./rules/errors');
const es6 = require('./rules/es6');
//conflict
// const stylistic = require('./rules/stylistic');
const variables = require('./rules/variables');
const flow = require('./rules/flow');
const classProperty = require('./rules/classProperty');
const header = require('./rules/header');
const sort = require('./rules/sort');

module.exports = {
  parser: 'babel-eslint',
  parserOptions: {
    ecmaVersion: 2017,
    sourceType: 'module',
    ecmaFeatures: {
      experimentalObjectRestSpread: true,
      jsx: true,
      modules: true
    }
  },
  env: {
    browser: true,
    node: true,
    commonjs: true,
    es6: true
  },
  // 以当前目录为根目录，不再向上查找 .eslintrc.js
  root: true,
  extends: ['prettier', 'prettier/flowtype'],
  rules: Object.assign(
    {
      'prettier/prettier': [
        'error',
        {
          printWidth: 120,
          semi: true,
          singleQuote: true,
          bracketSpacing: true,
          trailingComma: 'es5',
          jsxBracketSameLine: true,
        },
      ],
    },
    bestPractice,
    errors,
    es6,
    variables,
    flow,
    classProperty,
    header,
    sort
  ),
  plugins: ['flowtype', 'class-property', 'header', 'sort-imports-es6-autofix', 'html', 'prettier'],
  settings: {
    flowtype: {
      onlyFilesWithFlowAnnotation: true,
    },
  },
};
